MultipartVerifier

Trait MultipartVerifier 

pub trait MultipartVerifier<S> {
    // Required method
    fn multipart_verify(
        &self,
        msg: &[&[u8]],
        signature: &S,
    ) -> Result<(), Error>;
}
Equivalent of Verifier but the message is provided in non-contiguous byte slices.

Required Methods

fn multipart_verify(&self, msg: &[&[u8]], signature: &S) -> Result<(), Error>

Equivalent of Verifier::verify() but the message is provided in non-contiguous byte slices.

Errors

Returns Error if the provided signature is inauthentic for the given message.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors